
TYPE
	MC_ACP_ENCOD_REF : 	STRUCT  (*structure with information about ACOPOS encoder*)
		Axis : UDINT; (*axis reference*)
		Slot : USINT; (*slot for the ACOPOS plug in module where the encoder is read (3 or 4)*)
	END_STRUCT;
	MC_ACP_ENCOD_PARAM_REF : 	STRUCT  (*structure with parameters for homing an external encoder*)
		HomingMode : USINT; (*choice of the homing mode*)
		ReadOffset : BOOL; (*choice if the home offset will be read*)
		Position : REAL; (*position after successful homing*)
		Offset : DINT; (*homing offset*)
	END_STRUCT;
	MC_ADV_LIMITLOAD_REF :  STRUCT (*structure with parameters for torque limitation*)
	    LoadPosAccelParID : UINT; (*ParID with torque limit for acceleration in positive direction*)
	    LoadPosDecelParID : UINT; (*ParID with torque limit for deceleration in positive direction*)
	    LoadNegAccelParID : UINT; (*ParID with torque limit for acceleration in negative direction*)
	    LoadNegDecelParID : UINT; (*ParID with torque limit for deceleration in negative direction*)
	END_STRUCT;
	MC_ADV_OFFSETVELOCITY_REF : 	STRUCT  (*structure with parameter for velocity offset shift*)
		VelocityParID : UINT; (*use value of this ParID as velocity offset*)
		PosVelocityTriggerParID : UINT; (*add positive value of offset velocity*)
		NegVelocityTriggerParID : UINT; (*add negative value of offset velocity*)
	END_STRUCT;
	MC_ADVANCED_CUT_PAR_REF : 	STRUCT 
		CutOverspeed : INT; (*move synchronous to master or faster/slower*)
		CutterRadius : REAL; (*cutter radius to calculate CutRangeMaster if not specified*)
		NumberOfKnives : USINT; (*number of knives within one revolution of slave to calculate CutRangeMaster if not specified*)
		StartMode : UINT; (*start immediately, at a certain master position or perform restart*)
		CutPosition : REAL; (*knife is cutting material at this point*)
		FirstCutPosition : REAL; (*master position where the cutter should do first cut*)
		StartInterval : REAL; (*start interval on master axis*)
		MasterStartDistance : REAL; (*master distance for synchronizing the cutter to the first cut point*)
		CamTableID : USINT; (*user defined cam instead of standard linear cam e.g. for push out movement*)
		MasterParID : UINT; (*use this ParID on the master axis instead of the set position*)
		MasterMaxVelocity : REAL; (*maximum speed of the master axis or MasterParID*)
	END_STRUCT;
	MC_ADVANCED_GEAR_PAR_REF : 	STRUCT  (*structure for using additional functions for MC_BR_GearIn*)
		Acceleration : REAL; (*maximum acceleration for compensations *)
		Deceleration : REAL; (*maximum deceleration for stopping the slave axis*)
		JoltTime : REAL; (*jolt time for the compensations*)
		CompensationSelector : USINT; (*selection of the applied compensations*)
		MasterParID : UINT; (*use this ParID on the master axis instead of the set position*)
		MasterMaxVelocity : REAL; (*maximum speed of the master axis or MasterParID*)
	END_STRUCT;
	MC_ADVANCEDSHIFTPAR_REF : 	STRUCT  (*structure for using additional functions*)
		ShiftParID : UINT; (*ParID from which the offset shift is read*)
		MasterMaxVelocity : REAL; (*Master velocity for calculating the speed profile of the shift*)
	END_STRUCT;
	MC_ADV_OFFSETZONE_REF : 	STRUCT  (*structure for using additional functions*)
		ShiftParID : UINT; (*ParID from which the offset shift is read*)
		MasterMaxVelocity : REAL; (*Master velocity for calculating the speed profile of the shift*)
		Period : REAL; (*definition of period*)
		ProfileBasis : UINT; (*basis of movement profile*)
		ShiftMode : UINT; (*definition of how the value on the "Shift" input should be used*)
	END_STRUCT;
	MC_AUT_COMP_DATA_REF : 	STRUCT  (*structure for automat compensation check or calculation*)
		MaxMasterVelocity : REAL; (*maximal velocity of the master axis for the compensation path*)
		MasterCompDistance : REAL; (*compensation distance of master axis*)
		SlaveCompDistance : REAL; (*compensation distance of slave axis*)
		StartSlope : REAL; (*slope at the beginning of the compensation*)
		EndSlope : REAL; (*slope at the end of the compensation*)
		MaxSlaveCompVelocity : REAL; (*maximum speed of the slave axis in compensation*)
		MinSlaveCompVelocity : REAL; (*minimum speed of the slave axis in compensation*)
		MaxSlaveAccelComp1 : REAL; (*maximum acceleration of the slave axis in compensation phase 1*)
		MaxSlaveAccelComp2 : REAL; (*maximum acceleration of the slave axis in compensation phase 2*)
	END_STRUCT;
	MC_AUTDATA_TYP : 	STRUCT  (*structure for global cam automat parameters*)
		Master : UDINT; (*axis reference of the master*)
		StartPosition : REAL; (*start position of the master axis*)
		StartPositionDINT : DINT; (*start position of master axis in axis units*)
		StartInterval : REAL; (*start interval of the master axis*)
		EventStartPositionInInterval : ARRAY[0..4] OF REAL; (*relative start positions within the interval of the master axis*)
		StartState : USINT; (*index for the start state*)
		StartMaRelPos : REAL; (*relative master start position in the cam profile*)
		MasterStartPosMode : USINT; (*mode for event type ncS_START*)
		MaxMasterVelocity : REAL; (*maximum speed of the master axis*)
		MasterParID : UINT; (*parameter ID of the master axis*)
		AddMasterParID : UINT; (*parameter ID of the additive master axis*)
		AddSlaveParID : UINT; (*parameter ID of the additive slave axis*)
		SlaveFactorParID : UINT; (*ParID for the multiplication factor of the slave axis*)
		EventParID : UINT; (*parameter ID for event input when event type is ncPAR_ID1*)
		EventParID2 : UINT; (*parameter ID for event input when event type is ncPAR_ID2*)
		EventParID3 : UINT; (*parameter ID for event input when event type is ncPAR_ID3*)
		EventParID4 : UINT; (*parameter ID for event input when event type is ncPAR_ID4*)
		SlaveLatchParID : UINT; (*ParID for the latch value of the slave axis when the compensation mode is ncSL_LATCHPOS*)
		State : ARRAY[0..14] OF MC_AUTDATA_STATE_TYP; (*for definition of basis state and 14 other states*)
	END_STRUCT;
	MC_AUTDATA_EVENT_TYP : 	STRUCT  (*structure for defining events for state transitions*)
		Type : USINT; (*event type*)
		Attribute : USINT; (*event attribute*)
		Action : UDINT; (*action at state transition*)
		NextState : USINT; (*index for next state*)
	END_STRUCT;
	MC_AUTDATA_STATE_TYP : 	STRUCT  (*structure for defining up to 15 cam automat states*)
		DisableStateInit : USINT; (*internal variable*)
		CamProfileIndex : UINT; (*index of camprofile used in state*)
		MasterFactor : DINT; (*multiplication factor of the cam on the master axis*)
		SlaveFactor : DINT; (*multiplication factor of the cam on the slave axis*)
		CompMode : USINT; (*compansation mode*)
		MasterCompDistance : REAL; (*compensation distance of master axis*)
		SlaveCompDistance : REAL; (*compensation distance of slave axis*)
		RepeatCounterInit : UINT; (*start value state repeats for the ncCOUNT event*)
		RepeatCounterSet : UINT; (*counter state repeats for the ncCOUNT event*)
		MasterCamLeadIn : REAL; (*relative entry distance of master axis within the cam profile*)
		ExtendedCompLimits : UINT; (*extended compensation limits*)
		MinMasterCompDistance : REAL; (*minimum compensation distance for the master axis*)
		MinSlaveCompDistance : REAL; (*minimum compensation distance for the slave axis*)
		MaxSlaveCompDistance : REAL; (*maximum compensation distance for the slave axis*)
		MinSlaveCompVelocity : REAL; (*minimum speed of the slave axis in compensation*)
		MaxSlaveCompVelocity : REAL; (*maximum speed of the slave axis in compensation*)
		MaxSlaveAccelComp1 : REAL; (*maximum acceleration of the slave axis in compensation phase 1*)
		MaxSlaveAccelComp2 : REAL; (*maximum acceleration of the slave axis in compensation phase 2*)
		SlaveCompJoltTime : REAL; (*jolt time of the slave axis in the compensation*)
		MasterParID : UINT; (*Parameter ID of the master axis. 0 means global master ParID*)
		Event : ARRAY[0..4] OF MC_AUTDATA_EVENT_TYP; (*Definition of the event transition for the state*)
	END_STRUCT;
	MC_AUTINITOPTIONS_REF : 	STRUCT  (*structure with function block configuration*)
		GlobalParams : USINT; (*choose if global automat parameters should be transferred*)
		StateIndex : USINT; (*automat state index (0 to 14)*)
		EventIndex : USINT; (*automat event index (0 to 4)*)
		MaxStatesPerCycle : USINT; (*maximum number of states to be checked per task class cycle*)
		ParLock : USINT; (*lock for consistent online parameter change*)
		Force : BOOL; (*switch on or off force function*)
	END_STRUCT;
	MC_BRAKE_CONFIG_REF : 	STRUCT  (*structure with function block configuration*)
		BrakeTest : MC_BRAKE_TEST_REF; (*parameters for holding brake test*)
		BrakeMode : MC_BRAKE_MODE_REF; (*parameters for holding brake configuration*)
	END_STRUCT;
	MC_BRAKE_MODE_REF : 	STRUCT  (*parameters for holding brake configuration*)
		AutomaticControl : BOOL; (*automatic control on/off*)
		RestrictBrakeControl : BOOL; (*holding brake can be handled with turned on controller on/off*)
		ControlMonitoring : BOOL; (*control monitoring on/off*)
		MovementMonitoring : BOOL; (*movement monitoring on/off*)
		VoltageMonitoring : BOOL; (*voltage monitoring on/off*)
		TestAtPowerOn : BOOL; (*activate test when controller is switched on*)
		TestAtPowerOff : BOOL; (*activate test when controller is switched off*)
		AutomaticInductionStop : BOOL; (*automatic induction stop on/off*)
		ControlMonitoringFilterTime : REAL; (*control monitoring filter time *)
		EnableSBTRequestBySMC : BOOL; (*test activation by SafeMC module status*)
	END_STRUCT;
	MC_BRAKE_TEST_REF : 	STRUCT  (*parameters for holding brake test*)
		TestTorque : REAL; (*test torque for holding brake test*)
		TestDuration : REAL; (*test duration for holding brake test*)
		PositionLimit : REAL; (*position limit for holding brake test*)
		TestMode : BOOL; (*0 = Standard brake test mode; 1 = Safe brake test mode*)
	END_STRUCT;
	MC_BR_EVINPUT_REF : 	STRUCT  (*structure with input information about trigger*)
		EventSourceParID : UINT; (*ACOPOS ParID as event source*)
		Edge : USINT; (*edge selection for the trigger event*)
	END_STRUCT;
	MC_BR_TRIGGER_REF : 	STRUCT  (*structure with information about event source*)
		EventSourceParID : UINT; (*ParID as event source*)
		ProbeParID : UINT; (*ParID whose value should be saved on the drive*)
		Edge : USINT; (*edge selection for the trigger event*)
		MinWidth : REAL; (*minimum trigger event width for the event to be considered valid*)
		MaxWidth : REAL; (*maximum trigger event width for the event to be considered valid*)
		SensorDelay : DINT; (*trigger sensor delay [s]*)
	END_STRUCT;
	MC_CALC_CAM_CONFIG_REF : 	STRUCT  (*structure for configuring additional options for the interpolation*)
		Mode : UINT; (*interpolation mode*)
		CamType : BOOL; (*cyclic or noncyclic cam*)
		NumberOfPolynomials : USINT; (*maximum number of polynomials being calculated*)
		MasterPeriod : DINT; (*master period*)
		StartSlope : REAL; (*start slope (velocity) of the cam*)
		StartCurvature : REAL; (*start curvature (acceleration) of the cam*)
		EndSlope : REAL; (*end slope (velocity) of the cam*)
		EndCurvature : REAL; (*end curvature (acceleration) of the cam*)
	END_STRUCT;
	MC_CAMPROFILE_TYP : 	STRUCT  (*structure with cam profile data*)
		MasterPeriod : DINT; (*length of the master period*)
		SlavePeriod : DINT; (*length of the slave period*)
		PolynomialNumber : UDINT; (*number of polynomials*)
		PolynomialData : ARRAY[0..63] OF MC_POLYNOMIAL_DATA; (*polynomial coefficient*)
	END_STRUCT;
	MC_CAMSWITCH_REF : 	STRUCT  (*structure with the reference to the switching actions*)
		TrackNumber : INT; (*reference to the track*)
		FirstOnPosition : ARRAY[0..15] OF REAL; (*lower boundary where the switch is ON*)
		LastOnPosition : ARRAY[0..15] OF REAL; (*upper boundary where the switch is ON*)
		Period : REAL; (*definition of the period*)
	END_STRUCT;
	MC_CAM_SECTION_TYP : 	STRUCT  (*structure with data for MC_CAM_SECTIONS_TYP*)
		MasterPosition : REAL; (*master side starting position of the section*)
		SlavePosition : REAL; (*slave side starting position of the section*)
		FirstDerivative : REAL; (*speed in the starting point of the sections*)
		SecondDerivative : REAL; (*acceleration in the starting point of the section*)
		Mode : USINT; (*specification of master and slave position absolute or relative to the previous point*)
		Type : UINT; (*motion rule*)
		InflectionPoint : REAL; (*master position of the inflection point*)
	END_STRUCT;
	MC_CAM_SECTIONS_TYP : 	STRUCT  (*structure with data for the cam sections*)
		Section : ARRAY[0..64] OF MC_CAM_SECTION_TYP; (*data of a point and the subsequent section*)
	END_STRUCT;
	MC_CYCLIC_POSITION : 	STRUCT  (*structure with the cyclic position data *)
		Integer : DINT;
		Real : REAL;
	END_STRUCT;
	MC_CYCLIC_POSITION_REF :	STRUCT  (*structure with the cyclic position data *)
		Integer : DINT;
		Real : REAL;
	END_STRUCT;
	MC_CYCLIC_VALUE_REF : 	STRUCT  (*structure with the cyclic ParID value *)
		Integer : DINT;
		Real : REAL;
	END_STRUCT;
	MC_DATOBJ_REF : 	STRUCT  (*structure with parameters for saving trace data*)
		Name : STRING[32]; (*name of the data object or file*)
		Type : UINT; (*specifiy if a data object or a file is saved*)
		Format : UINT; (*specify the format of the saved data*)
		Device : STRING[32]; (*name of the file device*)
	END_STRUCT;
	MC_DRIVESTATUS_TYP : 	STRUCT  (*structure for the status information of the drive*)
		Simulation : BOOL; (*shows that the simulation mode is active*)
		NetworkInit : BOOL; (*shows that the network is initialized*)
		HomeSwitch : BOOL; (*shows that the digital reference switch input is active*)
		PosHWSwitch : BOOL; (*shows that the positive hardware end switch is active*)
		NegHWSwitch : BOOL; (*shows that the negative hardware end switch is active*)
		Trigger1 : BOOL; (*shows that the first trigger input is active*)
		Trigger2 : BOOL; (*shows that the second trigger input is active*)
		DriveEnable : BOOL; (*shows that the enable input is closed*)
		ControllerReady : BOOL; (*shows that the controller is ready to be turned on*)
		ControllerStatus : BOOL; (*shows that the controller is turned on*)
		HomingOk : BOOL; (*shows that the axis is referenced*)
		AxisError : BOOL; (*shows that at least one error or warning has occurred*)
		LagWarning : BOOL; (*shows that the lag error has exceeded the limit value specified for a warning*)
		ResetDone : BOOL; (*shows that the drive software was reset*)
	END_STRUCT;
	MC_ENDLESS_POSITION : 	STRUCT  (*structure to save the endless position*)
		EndlessPositionData : ARRAY[0..1] OF MC_ENDLESS_POSITION_DATA;
	END_STRUCT;
	MC_ENDLESS_POSITION_DATA : 	STRUCT  (*structure to save the endless position*)
		MTPhase : DINT;
		MTDiffInteger : DINT;
		MTDiffFract : DINT;
		RefOffset : DINT;
		Checksum : UDINT;
	END_STRUCT;
	MC_ENDLESS_POSITION_ACP_ENC_TYP : 	STRUCT  (*structure to save the endless position*)
		EndlessPositionDataAcpEnc : ARRAY[0..15] OF DINT;
	END_STRUCT;
	MC_ERRORRECORD_REF : 	STRUCT  (*structure with error messages that can occur after executing the command*)
		ParID : UINT; (*ParID at which the error occurred*)
		Number : UINT; (*error number*)
		Info : UDINT; (*additional information about the error number*)
		Type : USINT; (*type of the currently displayed error *)
	END_STRUCT;
	MC_ERRORTEXTCONFIG_REF : 	STRUCT  (*structure with function block configuration*)
		Format : UINT; (*format of the errortext*)
		LineLength : UINT; (*length of a line in the error text string*)
		DataLength : UINT; (*length of the error text string*)
		DataAddress : UDINT; (*address of the error text string*)
		DataObjectName : STRING[12]; (*name of the error text module*)
	END_STRUCT;
	MC_INPUT_REF : 	STRUCT  (*structure with reference to the input signal source*)
		Axis : UDINT; (*axis reference*)
		Slot : USINT; (*slot of the ACOPOS plug in module*)
		Channel : USINT; (*channel number of the input on the ACOPOS plug in module*)
	END_STRUCT;
	MC_MASTER_SWITCHES_REF : 	STRUCT  (*structure with master axis reference and switching data*)
		Master : UDINT; (*master axis reference*)
		Period : REAL; (*definition of period*)
		MasterStartPosition : REAL; (*start position of the cam switch *)
		Switches : ARRAY[0..4] OF MC_SWITCHES_REF; (*switching data*)
		MasterParID : UINT; (*use this ParID from the master axis instead of the set position*)
	END_STRUCT;
	MC_ADVANCED_MOVE_CYC_REF : 	STRUCT  (*structure with cyclic move extended parameters*)
        Velocity : REAL; (*maximum velocity*)
        Acceleration : REAL; (*maximum acceleration*)
        Deceleration : REAL; (*maximum deceleration*)
        SetValueParID : UINT; (*read the set value from this ParID instead of the set value input*)
        AdditiveParID : UINT; (*add the value of this ParID to the set value*)
        DisableJoltTime : BOOL; (*disable jolt limitation on the drive*)
        CoordinatedMovement : BOOL; (*set axis state to Synchronized Motion*)
	END_STRUCT;
	MC_NETTRACE_REF : 	STRUCT  (*structure with parameters for network command trace configuration*)
		Type : UDINT; (*trace type*)
		Reserve : UDINT; (*internal variable*)
	END_STRUCT;
	MC_NETTRACECONFIG_REF : 	STRUCT  (*structure with function block configuration*)
		DatObj : MC_DATOBJ_REF; (*parameters for saving the network trace data*)
		NetTrace : MC_NETTRACE_REF; (*parameters for network command trace configuration*)
	END_STRUCT;
	MC_OUTPUT_REF : 	STRUCT  (*structure with the reference to the signal output*)
		Axis : UDINT; (*axis reference*)
		Slot : USINT; (*slot of the ACOPOS plug-in module (2, 3, or 4)*)
		Channel : USINT; (*channel number of the output on the ACOPOS plug in module*)
	END_STRUCT;
	MC_OUTPUT_OPTIONS_REF : 	STRUCT  (*structure for output options*)
		Axis : UDINT; (*axis reference*)
		DestinationParID : UINT; (*destination ParID for the track*)
		Slot : USINT; (*slot of the ACOPOS plug-in module*)
		Channel : USINT; (*channel number of the output on the ACOPOS plug-in module*)
	END_STRUCT;
	MC_PARTRACE_REF : 	STRUCT  (*structure with parameter for axis trace configuration*)
		Type : UDINT; (*trace type*)
		Reserve : UDINT; (*internal variable*)
		TracingTime : REAL; (*maximum trace recording length*)
		SamplingTime : REAL; (*sampling interval of the ParIDs*)
		Delay : REAL; (*trigger delay*)
		NetTriggerDelay : REAL; (*delay time of the trigger via the network*)
		Trigger : MC_TRACETRIGGER_REF; (*parameters for trigger event*)
		Parameter : ARRAY[0..29] OF MC_TRACEPARAM_REF; (*parameters to record*)
	END_STRUCT;
	MC_PARTRACECONFIG_REF : 	STRUCT  (*structure with function block configuration*)
		DatObj : MC_DATOBJ_REF; (*parameters for saving the network trace data*)
		ParTrace : MC_PARTRACE_REF; (*parameters for axis trace configuration*)
	END_STRUCT;
	MC_POLYNOMIAL_DATA : 	STRUCT  (*structure with polynomial coefficient*)
		a : REAL;
		b : REAL;
		c : REAL;
		d : REAL;
		e : REAL;
		f : REAL;
		g : REAL;
		x : REAL; (*master end position of the polynomial*)
		Reserve : UDINT; (*internal variable*)
	END_STRUCT;
	MC_POWERDATA_REF : 	STRUCT  (*structure for the determined datas of the powermeter function*)
		IntervalNumber : UDINT; (*number of evaluated intervals*)
		IntervalDuration : DINT; (*ItervalTime of the last interval*)
		AverageActivePower : REAL; (*average effective Power*)
		AverageReactivePower : REAL; (*average idle Power*)
		MaximumActivePower : REAL; (*maximum effective Power*)
		MinimalActivePower : REAL; (*minimum effective Power*)
		ConsumedEnergy : REAL; (*used energy*)
		RegeneratedEnergy : REAL; (*produced energy*)
		EnergyBalance : REAL; (*spread between used and produced energy*)
		Reserve1 : REAL; (*reserve variable*)
		Reserve2 : REAL; (*reserve variable*)
		Reserve3 : REAL; (*reserve variable*)
		Reserve4 : REAL; (*reserve variable*)
		Reserve5 : REAL; (*reserve variable*)
	END_STRUCT;
	MC_POWER_STAGE_CHECK_REF : 	STRUCT  (*structure for configuration of the power stage checks *)
		CurrentFlowTestPhase1Off : BOOL; (*disable current flow test for phase 1*)
		CurrentFlowTestPhase2Off : BOOL; (*disable current flow test for phase 2*)
		CurrentFlowTestPhase3Off : BOOL; (*disable current flow test for phase 3*)
		OffsetCurrentWarningOff : BOOL; (*disable the current offset warning*)
		MotorSpeedWarningOff : BOOL; (*disable the motor speed warning*)
		OffsetCurrentMeasurementOff : BOOL; (*disable all offset current measurements *)
		CurrentFlowTestExtBleederOff : BOOL; (*disable current flow test for external bleeder*)
		CurrentFlowTestIntBleederOn : BOOL; (*enable current flow test for internal bleeder*)
		OCMonitoringExtBleederOff : BOOL; (*disable offset current monitoring of external bleeder*)
		SumCurrentMonitoringOff : BOOL; (*disable summation current monitoring*)
	END_STRUCT;
	MC_RECORD_INFO_REF : 	STRUCT  (*structure for cyclic read data info *)
		Record : ARRAY[0..7] OF MC_RECORD_REF;
	END_STRUCT;
	MC_RECORD_REF : 	STRUCT  (*structure for cyclic read data info*)
		Size : UINT;
		Reserve1 : UINT; (*alignment*)
		OneByteCount : USINT;
		TwoByteCount : USINT;
		FourByteCount : USINT;
		Reserve2 : USINT; (*alignment*)
		ParID : ARRAY[0..11]OF UINT;
		Reserve3 : ARRAY[0..3] OF UINT; (*internal variable*)
	END_STRUCT;
	MC_SETUP_CONTROLLER_CFG_REF : 	STRUCT  (*structure with the configuration parameters*)
		DatObj : MC_DATOBJ_REF; (*parameters for saving the setup data*)
		SetupControllerPar : MC_SETUP_CONTROLLER_PAR_REF; (*parameters for executing the controller setup*)
	END_STRUCT;
	MC_SETUP_CONTROLLER_PAR_REF : 	STRUCT  (*structure with parameters for the setup*)
		Mode : UINT; (*mode for the controller setup*)
		Orientation : USINT; (*orientation for the controller setup*)
		OperatingPoint : USINT; (*selection of the operating point for the controller setup*)
		MaxCurrentPercent : REAL; (*percentage of the rated current which is used durring Setup [%]*)
		MaxSpeedPercent : REAL; (*maximum speed of the movement in reference to the limits [%]*)
		MaxDistance : REAL; (*maximum distance which is moved durring the setup*)
		MaxLagError : REAL; (*maximum lag error which can occure durring the setup*)
		PropAmplificationPercent : REAL; (*percentage for proportional amplification [%]*)
		SignalOrder : UDINT; (*order of excitation signal*)
	END_STRUCT;
	MC_SETUP_IND_MOTOR_CFG_REF : 	STRUCT  (*structure with the configuration parameters*)
		DatObj : MC_DATOBJ_REF; (*parameters for saving the setup data*)
		SetupInductionMotorPar : MC_SETUP_IND_MOTOR_PAR_REF; (*parameters for executing the motor setup*)
	END_STRUCT;
	MC_SETUP_IND_MOTOR_PAR_OPT_REF : 	STRUCT  (*this parameters are only transered if they are not 0*)
		Phase : USINT; (*motor phase (1,2,3)*)
		PolePairs : USINT; (*numbers of polepairs*)
		VoltageConstant : REAL; (*voltage constant [mVmin]*)
		MaxSpeed : REAL; (*maximal numbers of revolutions [1/min]*)
		StallTorque : REAL; (*standstill torque [Nm]*)
		RatedTorque : REAL; (*rated torque [Nm]*)
		PeakTorque : REAL; (*maximum torque [Nm]*)
		TorqueConstant : REAL; (*torque constant [Nm/A]*)
		StallCurrent : REAL; (*standstill current [A]*)
		PeakCurrent : REAL; (*maximum current [A]*)
		MagnetizingCurrent : REAL; (*magnetizing current [A]*)
		PhaseCrossSection : REAL; (*cross section of one phase [mm]*)
		InvCharacteristicGain : REAL; (*gain of the inverter characteristic *)
		InvCharacteristicExponent : REAL; (*exponent of the inverter characteristic [1/A]*)
	END_STRUCT;
	MC_SETUP_IND_MOTOR_PAR_REF : 	STRUCT  (*structure with parameters for the setup*)
		Mode : UINT; (*mode of the motor setup*)
		RatedVoltage : REAL; (*rated voltage [V]*)
		RatedCurrent : REAL; (*rated current [A]*)
		RatedSpeed : REAL; (*rated numbers of revolutions [1/min]*)
		RatedFrequency : REAL; (*rated frequenzy [Hz]*)
		PowerFactor : REAL; (*cos phi*)
		ThermalTrippingTime : REAL; (*tripping time at thermal overload [s]*)
		OptionalData : MC_SETUP_IND_MOTOR_PAR_OPT_REF; (*optional parameters for the motorsetup*)
	END_STRUCT;
	MC_SETUP_ISQ_RIPPLE_CFG_REF : 	STRUCT  (*structure with the configuration parameters*)
		DatObj : MC_DATOBJ_REF; (*parameters for saving the setup data*)
		SetupIsqRipplePar : MC_SETUP_ISQ_RIPPLE_PAR_REF; (*structure with the parameters for the setup*)
	END_STRUCT;
	MC_SETUP_ISQ_RIPPLE_PAR_REF : 	STRUCT  (*structure with parameters for the setup*)
		Mode : UINT;
		RefSystem : UINT;
		PositionOffset : REAL;
		Velocity : REAL;
	END_STRUCT;
	MC_SETUP_MOTOR_PHA_CFG_REF : 	STRUCT  (*structure with configuration parameters*)
		DatObj : MC_DATOBJ_REF; (*parmeters for saving the setup data*)
		SetupMotorPhasingPar : MC_SETUP_MOTOR_PHA_PAR_REF; (*parmeters for executing the phasing setup*)
	END_STRUCT;
	MC_SETUP_MOTOR_PHA_PAR_REF : 	STRUCT  (*structure with parameters for the setup*)
		Mode : UINT; (*mode for the phasing setup*)
		Current : REAL; (*phasing current [A]*)
		Time : REAL; (*phasing time [s]*)
	END_STRUCT;
	MC_SETUP_OUTPUT_REF : 	STRUCT  (*structure where the output datas are written on*)
		Quality : REAL; (*quality  of the executed setup*)
		DataObjectIdent : UDINT; (*ident of the saved data object*)
	END_STRUCT;
	MC_SETUP_PHASING_RESULT_REF : 	STRUCT  (*structure with result data of phasing setup*)
		PolePairs : USINT; (*pole pairs*)
		CommutationOffset : REAL; (*commutation offset [rad]*)
	END_STRUCT;
	MC_SETUP_SYNC_MOTOR_CFG_REF : 	STRUCT  (*structure with parameters for the setup*)
		DatObj : MC_DATOBJ_REF; (*parameters for saving the setup data*)
		SetupSynchronMotorPar : MC_SETUP_SYNC_MOTOR_PAR_REF; (*parameters for executing the motor setup*)
	END_STRUCT;
	MC_SETUP_SYNC_MOTOR_PAR_OPT_REF : 	STRUCT  (*this parameters are only transferred if they are not 0*)
		Phase : USINT; (*motor phase (1,2,3)*)
		VoltageConstant : REAL; (*voltage constant [mVmin]*)
		MaxSpeed : REAL; (*maximal numbers of revolutions [1/min]*)
		StallTorque : REAL; (*standstill torque [Nm]*)
		TorqueConstant : REAL; (*torque constant [Nm/A]*)
		StallCurrent : REAL; (*standstill current [A]*)
		PhaseCrossSection : REAL; (*cross section of one phase [mm]*)
		InvCharacteristicGain : REAL; (*gain of the inverter characteristic *)
		InvCharacteristicExponent : REAL; (*exponent of the inverter characteristic [1/A]*)
	END_STRUCT;
	MC_SETUP_SYNC_MOTOR_PAR_REF : 	STRUCT  (*structure with parameters for the setup*)
		Mode : UINT; (*mode for the motor setup*)
		RatedVoltage : REAL; (*rated voltage [V]*)
		RatedCurrent : REAL; (*rated current [A]*)
		RatedSpeed : REAL; (*rated numbers of revolutions [1/min]*)
		RatedTorque : REAL; (*rated torque [Nm]*)
		PolePairs : USINT; (*number of polepairs*)
		PeakCurrent : REAL; (*maximal current [A]*)
		PeakTorque : REAL; (*maximal torque [Nm]*)
		ThermalTrippingTime : REAL; (*tripping time at thermal overload [s]*)
		OptionalData : MC_SETUP_SYNC_MOTOR_PAR_OPT_REF; (*optional parameter for the motor setup*)
	END_STRUCT;
	MC_SWITCHES_REF : 	STRUCT  (*structure with switches reference *)
		FirstOnPosition : ARRAY[0..63] OF REAL; (*lower boundary where the switch is ON*)
		LastOnPosition : ARRAY[0..63] OF REAL; (*upper boundary where the switch is ON*)
	END_STRUCT;
	MC_TRACETRIGGER_REF : 	STRUCT  (*structure with parameter for trigger events*)
		Axis : UDINT; (*axis reference*)
		ParID : UINT; (*trigger source ParID*)
		Event : USINT; (*trigger event*)
		Reserve : USINT; (*internal variable*)
		Threshold : REAL; (*threshold value*)
		Window : REAL; (*window around the threshold value*)
	END_STRUCT;
	MC_TRACEPARAM_REF : 	STRUCT  (*structure with parameter to record*)
		Axis : UDINT; (*axis reference*)
		ParID : UINT; (*ParID to record*)
		Reserve : UINT; (*internal variable*)
	END_STRUCT;
	MC_TRACK_OPTIONS_REF : 	STRUCT  (*structure with the reference track related properties*)
		OnCompensation : REAL; (*compensation time with which the switching on is advanced in time*)
		OffCompensation : REAL; (*compensation time with which the switching off is advanced in time*)
		Filter : REAL; (*filter time constant*)
		Hysteresis : REAL; (*distance from the switching point*)
		DisableNegativeDirection : BOOL; (*disable switches if master is moving in negative direction*)
	END_STRUCT;
	MC_TRACK_REF : 	STRUCT  (*structure with the reference track related properties*)
		OnCompensation : TIME; (*compensation time with which the switching on is advanced in time*)
		OffCompensation : TIME; (*compensation time with which the switching off is advanced in time*)
		Hysteresis : REAL; (*distance from the switching point*)
	END_STRUCT;
	MC_TRIGGER_REF : 	STRUCT  (*structure with data of trigger input signal source*)
		InputSource : USINT; (*source of the trigger event*)
		Edge : USINT; (*select the rising or the trailing edge of the trigger signal*)
		PosSource : USINT; (*select the position to be latched ncS_SET / ncS_ACT*)
		TouchProbeID : USINT; (*instance number of the touchprobe function on the selected drive (1 - 8)*)
	END_STRUCT;
	MC_PARID_INFO_REF : 	STRUCT  (*structure with result of MC_BR_ParIDInfo*)
		DataType : UINT; (*data type of ParID*)
		DataLength : UINT; (*data length of ParID in bytes*)
	END_STRUCT;
	MC_HW_INFO_DRIVE_REF : 	STRUCT  (*structure with information of drive HW*)
		ModelNumber : STRING[19]; (*model number of HW component*)
		SerialNumber : STRING[19]; (*serial number of HW component*)
		Revision : STRING[3]; (*revision of HW component*)
		MissionTimeEndDate : UDINT; (*end date of mission time (expiration date)*)
	END_STRUCT;
	MC_HW_INFO_CARD_REF : 	STRUCT  (*structure with information of plug-in card HW*)
		ModelNumber : STRING[19]; (*model number of HW component*)
		SerialNumber : STRING[19]; (*serial number of HW component*)
		Revision : STRING[3]; (*revision of HW component*)
	END_STRUCT;
	MC_HW_INFO_MOTOR_REF : 	STRUCT  (*structure with information of motor HW*)
		ModelNumber : STRING[19]; (*model number of HW component*)
		SerialNumber : STRING[19]; (*serial number of HW component*)
		Revision : STRING[3]; (*revision of HW component*)
	END_STRUCT;
	MC_HARDWARE_INFO_REF : 	STRUCT  (*structure with information of all HW component of a drive*)
		Drive : MC_HW_INFO_DRIVE_REF; (*HW information of drive*)
		Card : ARRAY[0..3] OF MC_HW_INFO_CARD_REF; (*HW information of plug-in cards*)
		Motor : ARRAY[0..1] OF MC_HW_INFO_MOTOR_REF; (*HW information of motors*)
	END_STRUCT;
	MC_SEND_INFO_REF : STRUCT (*information about a send channel*)
	    InUse : BOOL; (*channel currently in use*)
	    ParID : UINT; (*ParID transferred via this channel*)
	    ChangeAllowed: BOOL; (*parameter change of this channel is allowed*)
	END_STRUCT;
	MC_RECEIVE_INFO_REF : STRUCT (*information about a receive channel*)
	    InUse : BOOL; (*channel currently in use*)
	    ParID : UINT; (*ParID transferred via this channel*)
	    ChangeAllowed : BOOL; (*parameter change of this channel is allowed*)
	    SendNodeNumber : USINT; (*node number of the sending axis or station*)
	    SendAxisRef : UDINT;
	    SendAxisObjectName : STRING[48];
	    SendAxisDriveChannel : USINT; (*drive channel of the sending axis*)
	    SendAxisNetworkType : UINT; (*network type of the sending axis*)
	    SendAxisNetworkIndex : UINT; (*network index of the sending axis*)
	    InterpolationMode : USINT; (*interpolation mode of received data*)
	    DataOffset : UINT; (*bit offset within telegram*)
	    DataType : UINT; (*data type of received data*)
	END_STRUCT;
	MC_TRANSFER_INFO_REF : STRUCT   (*structure with ParID transfer info of an axis*)
	    SendChannel : ARRAY[0..3] OF MC_SEND_INFO_REF; (*information about a send channel*)
	    ReceiveChannel : ARRAY[0..5] OF MC_RECEIVE_INFO_REF; (*information about a receive channel*)
	END_STRUCT;
	MC_NET_ENC_INFO_REF : STRUCT   (*structure with information about network encoder*)
	    Type : USINT; (*encoder type*)
	    AdrDeviceString : UDINT; (*address of device string of encoder location*)
	    AdrPosition : UDINT; (*address of data point of encoder position*)
	    AdrPositionHW : UDINT; (*address of data point of encoder position higher 32 bits*)
	    AdrReferencePosition : UDINT; (*address of data point of encoder reference position*)
	    AdrReferenceCount : UDINT; (*address of data point of encoder reference counter*)
	    AdrPositionTime : UDINT; (*address of data point of encoder position time stamp*)
	    AdrEncoderStatus : UDINT; (*address of data point of encoder status*)
	END_STRUCT;
	MC_NET_ENC_PARAM_REF : STRUCT   (*structure with information about network encoder*)
	    ScaleIncrements : UDINT; (*increments per encoder revolution*)
	    IncValueRangeHW : UDINT; (*value range high word*)
	    IncValueRangeLW : UDINT; (*value range low word*)
	    ScaleUnits : UDINT; (*units per encoder revolutions*)
	    ScaleRevolutions : UDINT; (*encoder revolutions*)
	    CountDirection : USINT; (*count direction*)
	END_STRUCT;
	MC_NET_ENC_CONFIG_REF : STRUCT   (*structure with information about network encoder*)
	    Timeout : REAL; (*timeout for values change*)
	    Interpolation : BOOL; (*activate interpolation*)
	    Extrapolation : BOOL; (*activate extrapolation*)
	    FilterTime : REAL; (* time constant for position filter*)
	    NetworkCompensation : REAL; (*projection time for position*)
	END_STRUCT;
	MC_0068_IS_TYP : 	STRUCT  (*internal structure for MC_BR_HomeAcpEncoder*)
		C_Execute : BOOL; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_CommandAborted : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		LockID : USINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_EncoderOffset : DINT; (*internal variable*)
		C_HomingMode : USINT; (*internal variable*)
		C_HomingModeBits : USINT; (*internal variable*)
		C_ReadOffset : BOOL; (*internal variable*)
		C_Slot : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		BitIndex : UINT; (*internal variable*)
		C_Position : DINT; (*internal variable*)
		C_Offset : DINT; (*internal variable*)
		HomingStatusOffset : UINT; (*internal variable*)
		HomingStatusRecIndex : USINT; (*internal variable*)
		FbID : USINT; (*internal variable*)
		startTick : UDINT; (*internal variable*)
		C_NCHomingMode : USINT; (*internal variable*)
		Reserve1 : USINT; (*internal variable*)
		Reserve2 : UINT; (*internal variable*)
	END_STRUCT;
	MC_0069_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CyclicRead *)
		C_Valid : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_ParID : UINT; (*internal variable*)
		C_DataAddress : UDINT; (*internal variable*)
		C_DataType : UINT; (*internal variable*)
		C_Mode : UINT; (*internal variable*)
		Offset : UINT; (*internal variable*)
		RecIndex : USINT; (*internal variable*)
		ParIndex : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
	END_STRUCT;
	MC_0070_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CyclicWrite*)
		C_Valid : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_ParID : UINT; (*internal variable*)
		C_DataAddress : UDINT; (*internal variable*)
		C_DataType : UINT; (*internal variable*)
		C_Mode : UINT; (*internal variable*)
		ParIndex : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		DataLength : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		Reserve : UINT; (*internal variable*)
	END_STRUCT;
	MC_0071_IS_TYP : 	STRUCT  (*internal structure for MC_BR_Simulation*)
		C_Execute : BOOL; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		C_SimulationCommand : UINT; (*internal variable*)
	END_STRUCT;
	MC_0076_IS_TYP : 	STRUCT  (*internal structure for MC_BR_InitAutData*)
		C_Execute : BOOL; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_GlobalParams : USINT; (*internal variable*)
		C_StateIndex : USINT; (*internal variable*)
		C_EventIndex : USINT; (*internal variable*)
		C_MaxStatesPerCycle : USINT; (*internal variable*)
		C_ParLock : USINT; (*internal variable*)
		C_AutData : MC_AUTDATA_TYP; (*internal variable*)
		LockIDMa : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		C_Force : USINT; (*internal variable*)
		readSlot : USINT; (*internal variable*)
		sendSlot : USINT; (*internal variable*)
		paramCount : UINT; (*internal variable*)
		lockActive : BOOL; (*internal variable*)
		actStatesInCycle : USINT; (*internal variable*)
		stateCount : USINT; (*internal variable*)
		eventCount : USINT; (*internal variable*)
		stateParInImg : USINT; (*internal variable*)
		resetStates : BOOL; (*internal variable*)
		setStateIndex : BOOL; (*internal variable*)
		lastState : USINT; (*internal variable*)
		nextState : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		Reserve2 : UINT; (*internal variable*)
	END_STRUCT;
	MC_0077_IS_TYP : 	STRUCT  (*internal structure for MC_BR_GetErrorText*)
		C_Execute : BOOL; (*internal variable*)
		LockID : USINT; (*internal variable*)
		C_ErrorRecord : MC_ERRORRECORD_REF; (*internal variable*)
		C_Configuration : MC_ERRORTEXTCONFIG_REF; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0078_IS_TYP : 	STRUCT  (*internal structure for MC_BR_NetTrace*)
		C_Execute : BOOL; (*internal variable*)
		C_Command : UINT; (*internal variable*)
		C_Configuration : MC_NETTRACECONFIG_REF; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_ErrorRecord : MC_ERRORRECORD_REF; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0080_IS_TYP : 	STRUCT  (*internal structure for MC_BR_ParTrace*)
		C_Execute : BOOL; (*internal variable*)
		C_Command : UINT; (*internal variable*)
		C_Configuration : MC_PARTRACECONFIG_REF; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_ErrorRecord : MC_ERRORRECORD_REF; (*internal variable*)
		StartSaveStarted : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0081_IS_TYP : 	STRUCT  (*internal structure for MC_BR_MoveCyclicPosition*)
		C_CyclicPosition : MC_CYCLIC_POSITION; (*internal variable*)
		C_Velocity : REAL; (*internal variable*)
		C_Acceleration : REAL; (*internal variable*)
		C_Deceleration : REAL; (*internal variable*)
		C_PositionParID : UINT; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_CommandAborted : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_Valid : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_ReceiveParID : UINT; (*internal variable*)
		readSlot : UINT; (*internal variable*)
		Reserve1 : UINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0082_IS_TYP : 	STRUCT  (*internal structure for MC_BR_ReadCyclicPosition*)
		C_ParID : UINT; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_Valid : BOOL; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		C_CyclicPosition : MC_CYCLIC_POSITION; (*internal variable*)
		C_Offset : DINT; (*internal variable*)
		sendSlot : UINT; (*internal variable*)
		MnPResParIndex : UINT; (*internal variable*)
		LockIDMa : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		Reserve1 : USINT; (*internal variable*)
		Reserve2 : USINT; (*internal variable*)
	END_STRUCT;
	MC_0083_IS_TYP : 	STRUCT  (*internal structure for MC_BR_GetCamSlavePosition*)
		C_Execute : BOOL; (*internal variable*)
		C_DataAddress : UDINT; (*internal variable*)
		C_MasterPosition : REAL; (*internal variable*)
		C_MasterFactor : UDINT; (*internal variable*)
		C_SlaveFactor : DINT; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_SlavePosition : REAL; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0084_IS_TYP : 	STRUCT  (*internal structure for MC_BR_GetCamMasterPosition*)
		C_Execute : BOOL; (*internal variable*)
		C_DataAddress : UDINT; (*internal variable*)
		C_MasterStartPosition : REAL; (*internal variable*)
		C_SlavePosition : REAL; (*internal variable*)
		C_MasterFactor : UDINT; (*internal variable*)
		C_SlaveFactor : DINT; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_MasterPosition : REAL; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0088_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SetupInductionMotor*)
		C_Execute : BOOL; (*internal variable*)
		C_Command : UINT; (*internal variable*)
		C_Configuration : MC_SETUP_IND_MOTOR_CFG_REF; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_CommandAborted : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_SetupOutput : MC_SETUP_OUTPUT_REF; (*internal Variable*)
		LockIDPar : USINT; (*internal variable*)
		Reserve : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0089_IS_TYP : 	STRUCT  (*internal structure for MC_BR_PowerMeter*)
		C_Mode : USINT; (*internal variable*)
		C_IntervalTime : UINT; (*internal variable*)
		C_RestartInterval : BOOL; (*internal variable*)
		C_EventInput : MC_BR_EVINPUT_REF; (*internal variable*)
		C_Valid : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		CC_ErrorID : UINT; (*internal variable*)
		C_PowerData : MC_POWERDATA_REF; (*internal variable*)
		C_MissedIntervals : UINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		IntervalDurationOffset : UINT; (*internal variable*)
		IntervalDurationRecIndex : USINT; (*internal variable*)
		AverageActivePowerOffset : UINT; (*internal variable*)
		AverageActivePowerRecIndex : USINT; (*internal variable*)
		AverageReactivePowerOffset : UINT; (*internal variable*)
		AverageReactivePowerRecIndex : USINT; (*internal variable*)
		MaximumActivePowerOffset : UINT; (*internal variable*)
		MaximumActivePowerRecIndex : USINT; (*internal variable*)
		MinimalActivePowerOffset : UINT; (*internal variable*)
		MinimalActivePowerRecIndex : USINT; (*internal variable*)
		ConsumedEnergyOffset : UINT; (*internal variable*)
		ConsumedEnergyRecIndex : USINT; (*internal variable*)
		RegEnergyOffset : UINT; (*internal variable*)
		RegEnergyRecIndex : USINT; (*internal variable*)
		LockIDPmet : USINT; (*internal variable*)
		CDLockID : USINT; (*internal variable*)
		Reserve1 : UINT; (*internal variable*)
		Reserve2 : UINT; (*internal variable*)
		IntervalTimeMin : DINT; (*internal variable*)
		ParamCnt : USINT; (*Internal variable*)
		CountCnt : USINT; (*internal variable*)
		ParamArrayCount : UINT; (*internal variable*)
		CountOffset : ARRAY[0..7] OF UINT; (*internal variable*)
		CountRecIndex : ARRAY[0..7] OF USINT; (*internal variable*)
		saveParamCnt : USINT; (*internal variable*)
		firstFreeParam : USINT; (*internal variable*)
		lastFreeParam : USINT; (*internal variable*)
		dataConfigDone : BOOL; (*internal variable*)
		SptID : USINT; (*internal variable*)
		VarIndex : UINT; (*internal variable*)
		CompIndex : UINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		ReserveOffset01 : UINT; (*internal variable*)
		ReserveRecIndex01 : USINT; (*internal variable*)
		ReserveOffset02 : UINT; (*internal variable*)
		ReserveRecIndex02 : USINT; (*internal variable*)
		ReserveOffset03 : UINT; (*internal variable*)
		ReserveRecIndex03 : USINT; (*internal variable*)
		ReserveOffset04 : UINT; (*internal variable*)
		ReserveRecIndex04 : USINT; (*internal variable*)
		ReserveOffset05 : UINT; (*internal variable*)
		ReserveRecIndex05 : USINT; (*internal variable*)
		Reserve3 : UDINT; (*internal variable*)
		Reserve4 : UDINT; (*internal variable*)
		CyclicDataTaskClassCycleTime : UDINT; (*internal variable*)
		Reserve5 : USINT; (*internal variable*)
		Reserve6 : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0090_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SetupController*)
		C_Execute : BOOL; (*internal variable*)
		C_Command : UINT; (*internal variable*)
		C_Configuration : MC_SETUP_CONTROLLER_CFG_REF; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_CommandAborted : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_SetupOutput : MC_SETUP_OUTPUT_REF; (*internal Variable*)
		LockIDPar : USINT; (*internal variable*)
		Reserve : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0092_IS_TYP : 	STRUCT  (*internal structure for MC_BR_MoveCyclicVelocity*)
		C_CyclicVelocity : REAL; (*internal variable*)
		C_Direction : USINT; (*internal variable*)
		C_Acceleration : REAL; (*internal variable*)
		C_Deceleration : REAL; (*internal variable*)
		C_VelocityParID : UINT; (*internal variable*)
		C_Valid : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_CommandAborted : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_ReceiveParID : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		VarIndex : UINT; (*internal variable*)
		SptID : USINT; (*internal variable*)
		readSlot : UINT; (*internal variable*)
		Reserve1 : UINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		ArithIndex : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0093_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CalcCamFromPoints*)
		C_Configuration : MC_CALC_CAM_CONFIG_REF; (*internal variable*)
		state : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
	END_STRUCT;
	MC_0095_IS_TYP : 	STRUCT  (*Internal structure for MC_BR_VelocityControl*)
		Enable : BOOL; (*internal variable*)
		Reserve1 : USINT; (*alignment*)
		Reserve2 : USINT; (*alignment*)
		Reserve3 : USINT; (*alignment*)
		CyclicVelocity : REAL; (*internal variable*)
		CyclicVelocityCorrection : REAL; (*internal variable*)
		CyclicVelCorrPerRev : REAL; (*internal variable*)
		CyclicTorque : REAL; (*internal variable*)
		TorqueMode : USINT; (*internal variable*)
		Reserve4 : USINT; (*alignment*)
		Reserve5 : USINT; (*alignment*)
		Reserve6 : USINT; (*alignment*)
		Acceleration : REAL; (*internal variable*)
		Deceleration : REAL; (*internal variable*)
		SctrlKv : REAL; (*internal variable*)
		SctrlTn : REAL; (*internal variable*)
		InitSctrl : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Reserve : USINT; (*alignment*)
		ErrorID : UINT; (*internal variable*)
		SctrlInitialized : BOOL; (*internal variable*)
		DisableFBactive : BOOL; (*internal variable*)
		state : UINT; (*internal variable*)
		LastState : UINT; (*internal variable*)
		NextState : UINT; (*internal variable*)
		VarID : UINT; (*internal variable*)
		SptID : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockIDFb : USINT; (*internal variable*)
		CyclicVelParIndex : USINT; (*internal variable*)
		CyclicVelCorrParIndex : USINT; (*internal variable*)
		CyclicTorqueParIndex : USINT; (*internal variable*)
		ArithID : UINT; (*internal variable*)
		InitValue_SctrlKv : REAL; (*internal variable*)
		InitValue_SctrlTn : REAL; (*internal variable*)
		InitValue_tpredict : REAL; (*internal variable*)
		InitValue_S_ACT_PARID : UINT; (*internal variable*)
		prev_S_ACT_PARID_value : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		Reserve9 : USINT; (*alignment*)
		Reserve10 : USINT; (*alignment*)
		AxisScaleFactor : REAL; (*internal variable*)
	END_STRUCT;
	MC_0096_IS_TYP : 	STRUCT  (*internal structure for MC_TorqueControl*)
		Execute : BOOL; (*internal variable*)
		Reserve1 : USINT; (*alignment*)
		Reserve2 : USINT; (*alignment*)
		Reserve3 : USINT; (*alignment*)
		Torque : REAL; (*internal variable*)
		TorqueRamp : REAL; (*internal variable*)
		Velocity : REAL; (*internal variable*)
		Acceleration : REAL; (*internal variable*)
		InTorque : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Reserve4 : USINT; (*alignment*)
		ErrorID : UINT; (*internal variable*)
		AxisLimitActive : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		Reserve5 : UINT; (*alignment*)
		LastState : UINT; (*internal variable*)
		NextState : UINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		Reserve6 : USINT; (*alignment*)
		TctrlStatusOffset : UINT; (*internal variable*)
		TctrlStatusValue : UINT; (*internal variable*)
		TctrlStatusRecIdx : USINT; (*internal variable*)
		stateInTorque : USINT; (*internal variable*)
		SavedFrDrvCnt : USINT; (*internal variable*)
		WaitForTelegrams : USINT; (*internal variable*)
	END_STRUCT;
	MC_0097_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SetupMotorPhasing*)
		C_Execute : BOOL; (*internal variable*)
		C_Command : UINT; (*internal variable*)
		C_Configuration : MC_SETUP_MOTOR_PHA_CFG_REF; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_CommandAborted : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_SetupOutput : MC_SETUP_OUTPUT_REF; (*internal variable*)
		C_SetupResult : MC_SETUP_PHASING_RESULT_REF; (*internal variable*)
		Reserve1 : UDINT; (*internal variable*)
		Reserve2 : UDINT; (*internal variable*)
		Reserve3 : UDINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0098_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CyclicReadDataInfo*)
		Valid : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		tkNo : SINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		state : UINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		Reserve1 : USINT; (*alignment*)
		Reserve2 : UINT; (*alignment*)
		cycleTime : UDINT; (*internal variable*)
	END_STRUCT;
	MC_0099_IS_TYP : 	STRUCT  (*internal structure for MC_BR_AutomatCommand*)
		Enable : BOOL; (*internal variable*)
		Start : BOOL; (*internal variable*)
		Stop : BOOL; (*internal variable*)
		Restart : BOOL; (*internal variable*)
		Deceleration : REAL; (*internal variable*)
		EndAutomat : BOOL; (*internal variable*)
		SetSignal1 : BOOL; (*internal variable*)
		SetSignal2 : BOOL; (*internal variable*)
		SetSignal3 : BOOL; (*internal variable*)
		SetSignal4 : BOOL; (*internal variable *)
		ResetSignal1 : BOOL; (*internal variable*)
		ResetSignal2 : BOOL; (*internal variable*)
		ResetSignal3 : BOOL; (*internal variable*)
		ResetSignal4 : BOOL; (*internal variable*)
		TransferParLock : BOOL; (*internal variable*)
		SelectParLock : USINT; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Running : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		StandBy : BOOL; (*internal variable*)
		ParLockTransferred : BOOL; (*internal variable*)
		ActualStateIndex : USINT; (*internal variable*)
		InCam : BOOL; (*internal variable*)
		ActualStateCamIndex : UINT; (*internal variable*)
		InCompensation : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		cmdStart : BOOL; (*internal variable*)
		cmdStop : BOOL; (*internal variable*)
		cmdSetSignal : ARRAY[0..3] OF BOOL; (*internal variable*)
		cmdResetSignal : ARRAY[0..3] OF BOOL; (*internal variable*)
		cmdRestart : BOOL; (*internal variable*)
		cmdEndAutomat : BOOL; (*internal variable*)
		cmdParLock : BOOL; (*internal variable*)
		SptID : USINT; (*internal variable*)
		BitIndex : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		BitValue : UDINT; (*internal variable*)
		BitValueOffset : UINT; (*internal variable*)
		BitValueRecIndex : USINT; (*internal variable*)
		StateDataIdxRecIndex : USINT; (*internal variable*)
		StateDataIdxOffset : UINT; (*internal variable*)
		SignalSet : USINT; (*internal variable*)
		SignalReset : USINT; (*internal variable*)
		ParLockPending : BOOL; (*internal variable*)
		AutStatus : USINT; (*internal varibale*)
		AutActCamType : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		ChangeAxisState : BOOL; (*internal variable*)
		expectRunning : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
	END_STRUCT;
	MC_0100_IS_TYP : 	STRUCT  (*internal structure for MC_BR_TorqueControl*)
		Enable : BOOL; (*internal variable*)
		InitData : BOOL; (*internal variable*)
		StartSignal : BOOL; (*internal variable*)
		Reserve1 : USINT; (*alignment*)
		Torque : REAL; (*internal variable*)
		TorqueRamp : REAL; (*internal variable*)
		PosMaxVelocity : REAL; (*internal variable*)
		NegMaxVelocity : REAL; (*internal variable*)
		Acceleration : REAL; (*internal variable*)
		Mode : UINT; (*internal variable*)
		Reserve2 : UINT; (*alignment*)
		TimeLimit : UDINT; (*internal variable*)
		StartParID : UINT; (*internal variable*)
		TorqueParID : UINT; (*internal variable*)
		InTorque : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		StatEV_Move : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		DataInitialized : BOOL; (*internal variable*)
		WaitingForStart : BOOL; (*internal variable*)
		AxisLimitActive : BOOL; (*internal variable*)
		stateInTorque : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		Reserve3 : USINT; (*alignment*)
		LastState : UINT; (*internal variable*)
		NextState : UINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		BitRecIdx : USINT; (*internal variable*)
		BitOffset : UINT; (*internal variable*)
		BitValue : UINT; (*internal variable*)
		BitIndex : UINT; (*internal variable*)
		SavedFrDrvCnt : USINT; (*internal variable*)
		WaitForTelegrams : USINT; (*internal variable*)
		startTick : UDINT; (*internal variable*)
		MotorTorqueConst : REAL; (*internal variable*)
	END_STRUCT;
	MC_0101_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SetupIsqRipple*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Command : UINT; (*internal variable*)
		Configuration : MC_SETUP_ISQ_RIPPLE_CFG_REF; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		SetupOutput : MC_SETUP_OUTPUT_REF; (*internal variable*)
	END_STRUCT;
	MC_0102_IS_TYP : 	STRUCT  (*internal structure for MC_BR_ParTraceConfig*)
		C_Execute : BOOL; (*internal variable*)
		C_Command : UINT; (*internal variable*)
		C_AdrTraceConfig : UDINT; (*internal variable*)
		C_TraceConfig : MC_PARTRACE_REF; (*internal variable*)
		C_DataObject : MC_DATOBJ_REF; (*internal variable*)
		C_Done : BOOL; (*internal variable*)
		C_Busy : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_ErrorRecord : MC_ERRORRECORD_REF; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0103_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CheckAutCompensation*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		CompensationData : MC_AUT_COMP_DATA_REF; (*internal variable*)
		Mode : UINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		Result : REAL; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockIDFb : USINT; (*internal variable*)
		CurveIndex : UINT; (*internal variable*)
		compResult : REAL; (*internal variable*)
		C_MasterCompDistance : DINT; (*internal variable*)
		C_SlaveCompDistance : DINT; (*internal variable*)
		state : USINT; (*internal variable*)
		compStatus : USINT; (*internal variable*)
		Reserve : UINT; (*internal variable*)
	END_STRUCT;
	MC_0104_IS_TYP : 	STRUCT  (*internal structure for MC_BR_AxisErrorCollector*)
		Valid : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Reserve : USINT; (*alignment*)
		ErrorID : UINT; (*internal variable*)
		state : UINT; (*internal variable*)
	END_STRUCT;
	MC_0105_IS_TYP : 	STRUCT  (*internal structure for MC_BR_ReadAxisError*)
		Valid : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Reserve1 : BOOL; (*alignment*)
		ErrorID : UINT; (*internal variable*)
		state : UINT; (*internal variable*)
		pMessage : UDINT; (*internal variable*)
		Mode : UINT; (*internal variable*)
		Acknowledge : BOOL; (*internal variable*)
		ErrorRecordAvailable : BOOL; (*internal variable*)
		AcknowledgeAll : BOOL; (*internal variable*)
		Reserve2 : USINT; (*alignment*)
		Reserve3 : UINT; (*alignment*)
		Configuration : MC_ERRORTEXTCONFIG_REF; (*internal variable*)
		ErrorRecord : MC_ERRORRECORD_REF; (*internal variable*)
	END_STRUCT;
	MC_0106_IS_TYP : 	STRUCT  (*internal structure for MC_BR_GetParIDInfo*)
		Execute : BOOL; (*internal variable*)
		ParID : UINT; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		ParIDInfo : MC_PARID_INFO_REF; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0107_IS_TYP : 	STRUCT  (*internal structure for MC_BR_DigitalCamSwitch*)
		Enable : BOOL; (*internal variable*)
		Switches : MC_MASTER_SWITCHES_REF; (*internal variable*)
		SwitchSelector : USINT; (*internal variable*)
		Reserve1 : USINT; (*alignment*)
		OutputOptions : MC_OUTPUT_OPTIONS_REF; (*internal variable*)
		TrackOptions : MC_TRACK_OPTIONS_REF; (*internal variable*)
		Reserve2 : USINT; (*alignment*)
		camConInParID : UINT; (*internal variable*)
		EnableValue : BOOL; (*internal variable*)
		EnableParID : BOOL; (*internal variable*)
		EnableDigOut : BOOL; (*internal variable*)
		ChangeSwitches : BOOL; (*internal variable*)
		InitSwitches : BOOL; (*internal variable*)
		InitTrackOptions : BOOL; (*internal variable*)
		InOperation : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		SwitchesChanged : BOOL; (*internal variable*)
		SwitchesInitialized : BOOL; (*internal variable*)
		TrackOptionsInitialized : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		Value : BOOL; (*internal variable*)
		ActualSwitches : USINT; (*internal variable*)
		SptID : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		nextState : USINT; (*internal variable*)
		readSlot : USINT; (*internal variable*)
		sendSlot : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockIDMa : USINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		CamConActRecRecIndex : USINT; (*internal variable*)
		CamConActRecOffset : UINT; (*internal variable*)
		BitValueOffset : UINT; (*internal variable*)
		BitIndex : UINT; (*internal variable*)
		BitIndex1 : UINT; (*internal variable*)
		BitIndex2 : UINT; (*internal variable*)
		BitIndex3 : UINT; (*internal variable*)
		BitValueRecIndex : USINT; (*internal variable*)
		BitInput : ARRAY[0..2] OF USINT; (*internal variable*)
		neededBit : USINT; (*internal variable*)
		cntBit : USINT; (*internal variable*)
		BitValue : USINT; (*internal variable*)
		selectRecMode : USINT; (*internal variable*)
		CamConIndex : UINT; (*internal variable*)
		cntCam : UINT; (*internal variable*)
		cntTrack : USINT; (*internal variable*)
		CamConIndexAdmin : USINT; (*internal variable*)
		paramCount : UINT; (*internal variable*)
		bitFbMade : BOOL; (*internal variable*)
		edgeInitSwitches : BOOL; (*internal variable*)
		edgeChangeSwitches : BOOL; (*internal variable*)
		edgeInitTrackOptions : BOOL; (*internal variable*)
		edgeEnableParID : BOOL; (*internal variable*)
		edgeEnableDigOut : BOOL; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
	END_STRUCT;
	MC_0108_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SetHardwareInputs*)
		Enable : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		InputsSet : BOOL; (*internal variable*)
		cmdDigInForce : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		oldHomeSwitch : BOOL; (*internal variable*)
		oldPosHWSwitch : BOOL; (*internal variable*)
		oldNegHWSwitch : BOOL; (*internal variable*)
		oldTrigger1 : BOOL; (*internal variable*)
		oldTrigger2 : BOOL; (*internal variable*)
		Reserve1 : USINT; (*alignment*)
	END_STRUCT;
	MC_0109_IS_TYP : 	STRUCT  (*internal structure for MC_BR_GetHardwareInfo*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0110_IS_TYP : 	STRUCT  (*internal structure for MC_BR_BrakeControl*)
		Execute : BOOL; (*internal variable*)
		Command : USINT; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Configuration : MC_BRAKE_CONFIG_REF; (*internal variable*)
		Error : BOOL; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		PositionError : REAL; (*internal variable*)
		BrakeMode : UINT; (*internal variable*)
		BrakeStatusParID : UINT; (*internal variable*)
		Reserve1 : UINT; (*alignment*)
		BrakeStatus : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		startTick : UDINT; (*internal variable*)
	END_STRUCT;
	MC_0111_IS_TYP : 	STRUCT  (*internal structure for MC_BR_InitSendParID*)
		Execute : BOOL; (*internal variable*)
		SendChannel : USINT; (*internal variable*)
		ParID : UINT; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		AssignedSendChannel : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
		sendSlot : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
	END_STRUCT;
	MC_0112_IS_TYP : 	STRUCT  (*internal structure for MC_BR_InitReceiveParID*)
		Execute : BOOL; (*internal variable*)
		InterpolationMode : USINT; (*internal variable*)
		ParID : UINT; (*internal variable*)
		SendChannel : USINT; (*internal variable*)
		ReceiveChannel : USINT; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		ReceiveParID : UINT; (*internal variable*)
		sendSlot : USINT; (*internal variable*)
		readSlot : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
	END_STRUCT;
	MC_0113_IS_TYP : 	STRUCT  (*internal structure for MC_BR_ReceiveParIDOnPLC*)
		ParID : UINT; (*internal variable*)
		sendSlot : USINT; (*internal variable*)
		Mode : USINT; (*internal variable*)
		Valid : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		CyclicValue : MC_CYCLIC_VALUE_REF; (*internal variable*)
		Offset : DINT; (*internal variable*)
	END_STRUCT;
	MC_0114_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CrossCutterControl*)
		InitData : BOOL; (*internal variable*)
		EnableCut : BOOL; (*internal variable*)
		EnableCutStateSet : USINT; (*internal variable*)
		Reserve1 : USINT; (*internal variable*)
		MaFactor : DINT; (*internal variable*)
		CutRangeMaster : DINT; (*internal variable*)
		CutRangeSlave : DINT; (*internal variable*)
		ProductLength : DINT; (*internal variable*)
		ProductLengthCorrection : DINT; (*internal variable*)
		MasterDistance : DINT; (*internal variable*)
		SlaveFirstDistance : DINT; (*internal variable*)
		SlaveLastDistance : DINT; (*internal variable*)
		SlaveFullDistance : DINT; (*internal variable*)
		MaStartPos : DINT; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		DataInitialized : BOOL; (*internal variable*)
		StandBy : BOOL; (*internal variable*)
		CamAutActive : BOOL; (*internal variable*)
		InCompensation : BOOL; (*internal variable*)
		InCut : BOOL; (*internal variable*)
		InCutPrevCycle : BOOL; (*internal variable*)
		Reserve2 : USINT; (*internal variable*)
		cntResetCorrection : USINT; (*internal variable*)
		CutCount : UDINT; (*internal variable*)
		CutMasterPosition : DINT; (*internal variable*)
		CutOverspeed : INT; (*internal variable*)
		StartMode : UINT; (*internal variable*)
		CutPosition : DINT; (*internal variable*)
		FirstCutPosition : DINT; (*internal variable*)
		StartInterval : DINT; (*internal variable*)
		MasterStartDistance : DINT; (*internal variable*)
		CamTableID : USINT; (*internal variable*)
		Reserve3 : USINT; (*internal variable*)
		MasterParID : UINT; (*internal variable*)
		MasterMaxVelocity : REAL; (*internal variable*)
		state : USINT; (*internal variable*)
		LastState : USINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		sendSlot : USINT; (*internal variable*)
		readSlot : USINT; (*internal variable*)
		LockIDMa : USINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		AutMaOffsetRecIdx : USINT; (*internal variable*)
		CompBitInfoRecIdx : USINT; (*internal variable*)
		oldCamTypeValue : USINT; (*internal variable*)
		CamTypeValue : USINT; (*internal variable*)
		AutStatus : USINT; (*internal variable*)
		AutMaOffsetOffset : UINT; (*internal variable*)
		CompBitInfoOffset : UINT; (*internal variable*)
		oldMasterOffsetValue : DINT; (*internal variable*)
		ArithIndex : UINT; (*internal variable*)
		BitIndex : UINT; (*internal variable*)
		AutActStIdx : USINT; (*internal variable*)
		Reserve4 : USINT; (*internal variable*)
		LatchIndex : UINT; (*internal variable*)
		newCutPositionDiff : DINT; (*internal variable*)
		DownloadedCutPosition : DINT; (*internal variable*)
		ActualUsedCutPosition : DINT; (*internal variable*)
		IMG_Var_I4_2 : DINT; (*internal variable*)
		VarIndex : UINT; (*internal variable*)
		VarParIndex : UINT; (*internal variable*)
		DelayIndex : UINT; (*internal variable*)
		CountIndex : UINT; (*internal variable*)
		EvwrIndex : UINT; (*internal variable*)
		MuxIndex : UINT; (*internal variable*)
		LogicIndex : UINT; (*internal variable*)
		Reserve7 : UINT; (*internal variable*)
		CutterRadius : REAL; (*internal variable*)
		NumberOfKnives : USINT; (*internal variable*)
		correctCurrentCycle : BOOL; (*internal variable*)
		Reserve8 : UINT; (*internal variable*)
		IMG_State1_addDistance : DINT; (*internal variable*)
	END_STRUCT;
	MC_0115_IS_TYP : 	STRUCT  (*internal structure for MC_BR_InitReceiveNetworkData*)
		Execute : BOOL; (*internal variable*)
		NodeNumber : USINT; (*internal variable*)
		BitOffset : UINT; (*internal variable*)
		DataType : UINT; (*internal variable*)
		InterpolationMode : USINT; (*internal variable*)
		ReceiveChannel : USINT; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		ReceiveParID : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		readSlot : USINT; (*internal variable*)
	END_STRUCT;
	MC_0116_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SaveCamProfileObj*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		DataObjectVersion : UINT; (*internal variable*)
		DataObjectName : STRING[12]; (*internal variable*)
		DataAddress : UDINT; (*internal variable*)
		DataLength : UDINT; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		ErrorRecord : MC_ERRORRECORD_REF; (*internal variable*)
		DataObjectIdent : UDINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockID : USINT; (*internal varibale*)
		hexVersion : UINT; (*internal variable *)
	END_STRUCT;
	MC_0118_IS_TYP : 	STRUCT  (*internal structure for MC_BR_JogVelocity*)
		Velocity : REAL; (*internal variable*)
		Acceleration : REAL; (*internal variable*)
		Deceleration : REAL; (*internal variable*)
		Enable : BOOL; (*internal variable*)
		JogPositive : BOOL; (*internal variable*)
		JogNegative : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Jogging : BOOL; (*internal varibale*)
		ErrorID : UINT; (*internal variable*)
		Direction : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		moveActive : BOOL; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		Reserve : UINT; (*internal variable*)
		C_Velocity : REAL; (*internal variable*)
		C_Acceleration : REAL; (*internal variable*)
		C_Deceleration : REAL; (*internal variable*)
	END_STRUCT;
	MC_0119_IS_TYP : 	STRUCT  (*internal structure for MC_BR_JogLimitPosition*)
		Velocity : REAL; (*internal variable*)
		Acceleration : REAL; (*internal variable*)
		Deceleration : REAL; (*internal variable*)
		FirstPosition : DINT; (*internal variable*)
		LastPosition : DINT; (*internal variable*)
		Enable : BOOL; (*internal variable*)
		JogPositive : BOOL; (*internal variable*)
		JogNegative : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		Jogging : BOOL; (*internal varibale*)
		ErrorID : UINT; (*internal variable*)
		LimitReached : BOOL; (*internal variable*)
		Direction : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		C_Velocity : REAL; (*internal variable*)
		C_Acceleration : REAL; (*internal variable*)
		C_Deceleration : REAL; (*internal variable*)
		targetPosition : DINT; (*internal variable*)
		startOffset : DINT; (*internal variable*)
		CommandedOffset : DINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		moveActive : BOOL; (*internal variable*)
		Reserve : USINT; (*internal variable*)
	END_STRUCT;
	MC_0120_IS_TYP : 	STRUCT  (*internal structure for MC_BR_JogTargetPosition*)
		Velocity : REAL; (*internal variable*)
		Acceleration : REAL; (*internal variable*)
		Deceleration : REAL; (*internal variable*)
		TargetPosition : DINT; (*internal variable*)
		Enable : BOOL; (*internal variable*)
		JogToTarget : BOOL; (*internal variable*)
		JogPositive : BOOL; (*internal variable*)
		JogNegative : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		Jogging : BOOL; (*internal variable*)
		MovingToTarget : BOOL; (*internal variable*)
		TargetReached : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		Direction : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		moveActive : BOOL; (*internal variable*)
		Reserve : USINT; (*internal variable*)
		C_Velocity : REAL; (*internal variable*)
		C_Acceleration : REAL; (*internal variable*)
		C_Deceleration : REAL; (*internal variable*)
		startOffset : DINT; (*internal variable*)
		CommandedOffset : DINT; (*internal variable*)
		targetPosition : DINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		Reserve1 : UINT; (*internal variable*)
	END_STRUCT;
	MC_0121_IS_TYP : 	STRUCT  (*internal structure for MC_BR_GetParIDTransferInfo*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
	END_STRUCT;
	MC_0122_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CalcSectionsFromCam*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		Reserve1 : UINT; (*internal variable*)
		DataAddress : UDINT; (*internal variable*)
		CamDataAddress : UDINT; (*internal variable*)
		DataObjectName : STRING[12]; (*internal variable*)
		state : USINT; (*internal variable*)
		Reserve2 : UINT; (*internal variable*)
	END_STRUCT;
	MC_0123_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CalcPointsFromCam*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		MasterPointsAddress : UDINT; (*internal variable*)
		SlavePointsAddress : UDINT; (*internal variable*)
		NumberOfPoints : UINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		AdditionalInfo : MC_CALC_CAM_CONFIG_REF; (*internal variable*)
		DataObjectName : STRING[12]; (*internal variable*)
		state : USINT; (*internal variable*)
		Reserve  : UINT; (*internal variable*)
		DataAddress : UDINT; (*internal variable*)
	END_STRUCT;
	MC_0124_IS_TYP : 	STRUCT  (*internal structure for MC_BR_MoveCyclicPositionExt*)
	    CyclicPosition : MC_CYCLIC_POSITION_REF; (*internal variable*)
	    AdvancedParameters : MC_ADVANCED_MOVE_CYC_REF; (*internal variable*)
	    InterpolationMode : USINT; (*internal variable*)
	    Valid : BOOL; (*internal variable*)
	    Busy : BOOL; (*internal variable*)
	    CommandAborted : BOOL; (*internal variable*)
	    Error : BOOL; (*internal variable*)
		MoveID : USINT; (*internal variable*)
	    ErrorID : UINT; (*internal variable*)
	    ReceiveParID : UINT; (*internal variable*)
		readSlot : UINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		ArithIndex : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		Reserve : UINT; (*internal variable*)
	END_STRUCT;
	MC_0125_IS_TYP : 	STRUCT  (*internal structure for MC_BR_MoveCyclicVelocityExt*)
		CyclicVelocity : REAL; (*internal variable*)
	    AdvancedParameters : MC_ADVANCED_MOVE_CYC_REF; (*internal variable*)
		Direction : USINT; (*internal variable*)
	    InterpolationMode : USINT; (*internal variable*)
		Valid : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		ReceiveParID : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		readSlot : UINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		ArithIndex : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
		Reserve1 : USINT; (*internal variable*)
	END_STRUCT;
	MC_0126_IS_TYP : 	STRUCT  (*internal structure for MC_BR_GearIn*)
		RatioNumerator : DINT; (*internal variable*)
		RatioDenominator : DINT; (*internal variable*)
		AdvancedParameters : MC_ADVANCED_GEAR_PAR_REF; (*internal variable*)
		InitData : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		Active : BOOL; (*internal variable*)
		InGear : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		DataInitialized : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		LockIDSend : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		sendSlot : USINT; (*internal variable*)
		readSlot : USINT; (*internal variable*)
		MoveID : USINT; (*internal variable*)
		LockIDMa : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		AutActStateIndexRecIndex : USINT; (*internal variable*)
		AutActStateIndexOffset : UINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		flagInitData : BOOL; (*internal variable*)
		MasterParID : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		gearRatioChanged : BOOL; (*internal variable*)
		maxMasterVelChanged : BOOL; (*internal variable*)
		usedAccel : REAL; (*internal variable*)
		SavedFrDrvCnt : USINT; (*internal variable*)
		WaitForTelegrams : BOOL; (*internal variable*)
	END_STRUCT;

	MC_0127_IS_TYP : 	STRUCT  (*internal structure for MC_BR_OffsetVelocity*)
		CyclicVelocity : REAL; (*internal variable*)
		Acceleration : REAL; (*internal variable*)
	    AdvancedParameters : MC_ADV_OFFSETVELOCITY_REF; (*internal variable*)
	    Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		ActualShiftValue: REAL; (*internal variable*)
		VarIndex : UINT; (*internal variable*)
		MpgenIndex : UINT; (*internal variable*)
		MuxIndex : UINT; (*internal variable*)
		BitIndex : UINT; (*internal variable*)
		CmpIndex : UINT; (*internal variable*)
		ArithIndex : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		AxisState : UINT; (*internal variable*)
		MpgenStatus : USINT; (*internal variable*)
        FbID : USINT; (*internal variable*)
		VelocityAttained: BOOL; (*internal variable*)
		MpgenStatusRecIndex : USINT; (*internal variable*)
		MpgenStatusOffset : UINT; (*internal variable*)
		MpgenValueOffset : UINT; (*internal variable*)
		MpgenValueRecIndex : USINT; (*internal variable*)
		SavedToDrvCnt : USINT; (*internal variable*)
		VarParIndex : UINT; (*internal variable*)
		WaitForTelegrams : BOOL; (*internal variable*)
		OldCyclicVelocity : REAL; (*internal variable*)
	END_STRUCT;
	MC_0128_IS_TYP : 	STRUCT  (*internal structure for MC_BR_OffsetZone*)
	    Shift : REAL; (*internal variable*)
		Velocity : REAL; (*internal variable*)
		Acceleration : REAL; (*internal variable*)
		ZoneStartPosition : REAL; (*internal variable*)
		ZoneEndPosition : REAL; (*internal variable*)
	    AdvancedParameters : MC_ADV_OFFSETZONE_REF; (*internal variable*)
	    InitData : BOOL; (*internal variable*)
	    Active : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		C_Error : BOOL; (*internal variable*)
		ShiftAttained: BOOL; (*internal variable*)
		DataInitialized: BOOL; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		MpgenStatus : USINT; (*internal variable*)
        FbID : USINT; (*internal variable*)
		ActualShiftValue: REAL; (*internal variable*)
		VarIndex : UINT; (*internal variable*)
		MpgenIndex : UINT; (*internal variable*)
		CamConIndex : UINT; (*internal variable*)
		EvwrIndex : UINT; (*internal variable*)
		AxisState : UINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		MpgenStatusRecIndex : USINT; (*internal variable*)
		MpgenStatusOffset : UINT; (*internal variable*)
		MpgenValueOffset : UINT; (*internal variable*)
		MpgenValueRecIndex : USINT; (*internal variable*)
		InitDataActive : BOOL; (*internal variable*)
		VarParIndex : UINT; (*internal variable*)
		SlaveFactor : UDINT; (*internal variable*)
		SlaveRtN : REAL; (*internal variable*)
		ProfileBasisFactor : UDINT; (*internal variable*)
		ProfileBasisRtN : REAL; (*internal variable*)
	END_STRUCT;
	MC_0129_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SetupSynchronMotor*)
		Execute : BOOL; (*internal variable*)
		Command : UINT; (*internal variable*)
		Configuration : MC_SETUP_SYNC_MOTOR_CFG_REF; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		SetupOutput : MC_SETUP_OUTPUT_REF; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0130_IS_TYP : 	STRUCT  (*internal structure for MC_BR_CheckEndlessPosition*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		EndlessPositionInitialized : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		DataValid: BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0133_IS_TYP : 	STRUCT  (*internal structure for MC_LimitLoad*)
		Direction : USINT; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Ready : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		Error : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		SptID : USINT; (*internal variable*)
		TlimStatusRecIndex : USINT; (*internal variable*)
		TlimStatusOffset : UINT; (*internal variable*)
		VarIndex : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		ParIndex : USINT; (*internal variable*)
		VarParIDOffset: USINT; (*internal variable*)
	END_STRUCT;
	MC_0134_IS_TYP : 	STRUCT  (*internal structure for MC_BR_LimitLoad*)
		Mode : USINT; (*internal variable*)
		InitData : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Ready : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		DataInitialized : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		SptID : USINT; (*internal variable*)
		TlimStatusRecIndex : USINT; (*internal variable*)
		TlimStatusOffset : UINT; (*internal variable*)
		VarIndex : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		ParIndex : USINT; (*internal variable*)
		ParameterInitFlags : USINT; (*internal variable*)
		OldLoadPosAccel : REAL; (*internal variable*)
		OldLoadPosDecel : REAL; (*internal variable*)
		OldLoadNegAccel : REAL; (*internal variable*)
		OldLoadNegDecel : REAL; (*internal variable*)
		AdvancedParameters : MC_ADV_LIMITLOAD_REF; (*internal variable*)
	END_STRUCT;
	MC_0135_IS_TYP : 	STRUCT  (*internal structure for MC_BR_LimitLoadCam*)
		Mode : USINT; (*internal variable*)
		InitData : BOOL; (*internal variable*)
		DataInitialized : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		CamProfileIndexPos : UINT; (*internal variable*)
		CamProfileIndexNeg : UINT; (*internal variable*)
		PositionFactorPos : DINT; (*internal variable*)
		LoadFactorPos : DINT; (*internal variable*)
		PositionFactorNeg : DINT; (*internal variable*)
		LoadFactorNeg : DINT; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Ready : BOOL; (*internal variable*)
		Active : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		NextState : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockID : USINT; (*internal variable*)
		SptID : USINT; (*internal variable*)
		TlimStatusRecIndex : USINT; (*internal variable*)
		ParIndex : USINT; (*internal variable*)
		TlimStatusOffset : UINT; (*internal variable*)
		CurveIndex : UINT; (*internal variable*)
		C_ErrorID : UINT; (*internal variable*)
		ParameterInitFlags : USINT; (*internal variable*)
		Reserve1 : USINT; (*internal variable*)
	END_STRUCT;
	MC_0137_IS_TYP : 	STRUCT  (*internal structure for MC_BR_ConfigPowerStageChecks*)
		Execute : BOOL; (*internal variable*)
		Configuration : MC_POWER_STAGE_CHECK_REF; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		MotorTestMode : UDINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
	END_STRUCT;
	MC_0136_IS_TYP : 	STRUCT  (*internal structure for MC_BR_ResetAutPar*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		GlobalParams : USINT; (*internal variable*)
		StateIndex : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
	END_STRUCT;
	MC_0138_IS_TYP : 	STRUCT  (*internal structure for MC_BR_InitEndlessPosAcpEnc*)
		ErrorID : UINT; (*internal variable*)
		Error : BOOL; (*internal variable*)
		slot : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		DataValid : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
	END_STRUCT;
	MC_0139_IS_TYP : 	STRUCT  (*internal structure for MC_BR_NetworkInit*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		Command : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
	MC_0140_IS_TYP : 	STRUCT (*internal structure for MC_BR_CommandError*)
		Execute  : BOOL; (*internal variable*)
		Done  : BOOL; (*internal variable*)
		Busy  : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		Command : UINT; (*internal variable*)
		state : USINT; (*internal variable*)
	END_STRUCT;
    MC_NET_ENC_INTERN_TYP : STRUCT (*internal structure for network encoder*)
        AdrChannelName : UDINT; (*internal variable*)
        DataType : UINT; (*internal variable*)
        BitOffset : UINT; (*internal variable*)
        readSlot : USINT; (*internal variable*)
        Reserve1 : USINT; (*internal variable*)
        Reserve2 : UINT; (*internal variable*)
    END_STRUCT;
	MC_0141_IS_TYP : 	STRUCT  (*internal structure for MC_BR_InitReceiveNetworkEnc*)
		Execute : BOOL; (*internal variable*)
		EncoderInformation : MC_NET_ENC_INFO_REF; (*internal variable*)
		EncoderParameters : MC_NET_ENC_PARAM_REF; (*internal variable*)
        ReceiveConfiguration : MC_NET_ENC_CONFIG_REF; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		state : USINT; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		PositionParID : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		LockIDReceive : USINT; (*internal variable*)
		EncoderNodeNumber : USINT; (*internal variable*)
		Reserve1 : USINT; (*internal variable*)
		EncoderInternal : ARRAY[0..5] OF MC_NET_ENC_INTERN_TYP; (*internal variable*)
	END_STRUCT;
	MC_0145_IS_TYP : 	STRUCT  (*internal structure for MC_BR_SetupFromParTabObj*)
		Execute : BOOL; (*internal variable*)
		Done : BOOL; (*internal variable*)
		Command : UINT; (*internal variable*)
		SetupOutput : MC_SETUP_OUTPUT_REF; (*internal variable*)
		Busy : BOOL; (*internal variable*)
		CommandAborted : BOOL; (*internal variable*)
		Error : BOOL; (*internal variable*)
		ErrorID : UINT; (*internal variable*)
		LockIDPar : USINT; (*internal variable*)
		state : USINT; (*internal variable*)
		DataObjectName : STRING[12]; (*internal variable*)
	END_STRUCT;
END_TYPE
